@@ -49,7 +49,7 @@ namespace gcomm
     std::string const Defaults::PcNpvo                  = "false";
     std::string const Defaults::PcVersion               = "0";
     std::string const Defaults::PcWaitPrim              = "true";
-    std::string const Defaults::PcWaitPrimTimeout       = "P30S";
+    std::string const Defaults::PcWaitPrimTimeout       = "PT30S";
     std::string const Defaults::PcWeight                = "1";
-    std::string const Defaults::PcRecovery              = "1";
+    std::string const Defaults::PcRecovery              = "true";
 }
